!$Header: /home/ssipsl/CVSREP/ORCHIDEE/src_parameters/constantes.f90,v 1.16 2007/08/01 15:19:05 ssipsl Exp $
!IPSL (2006)
! This software is governed by the CeCILL licence see ORCHIDEE/ORCHIDEE_CeCILL.LIC
!-
MODULE constantes
!!--------------------------------------------------------------------
!! "constantes" module contains some public technical constants
!!--------------------------------------------------------------------
  USE defprec
  USE parallel
!-
  IMPLICIT NONE
!-
! To set for more printing
  LOGICAL,SAVE :: long_print = .FALSE.
!-
! One of the most frequent problems is a temperature out of range
! we provide here a way to catch that in the calling procedure. (JP)
  LOGICAL,PARAMETER :: diag_qsat = .TRUE.
!-
! Selects the type of output for the model.
! Value is read from run.def in intersurf_history.
  LOGICAL           :: almaoutput
!-
! One day in seconds
  REAL(r_std),SAVE :: one_day
! One year in seconds
  REAL(r_std),SAVE :: one_year
! Earth radius ~= Equatorial radius
! The Earth's equatorial radius a, or semi-major axis, is the distance from its center to the equator and equals 6,378.1370 km.
! The equatorial radius is often used to compare Earth with other planets.
  REAL(r_std), PARAMETER                          :: R_Earth = 6378000.
!The meridional mean is well approximated by the semicubic mean of the two axe yielding 6367.4491 km
! or less accurately by the quadratic mean of the two axes about 6,367.454 km
! or even just the mean of the two axes about 6,367.445 km.
!-
! No comment
  REAL(r_std),PARAMETER :: pi=3.141592653589793238
!-
! 0 degre Celsius in degre Kelvin
  REAL(r_std),PARAMETER :: tp_00=273.15
!-
! Specific value if no restart value
  REAL(r_std),SAVE :: val_exp = 999999.
!-
! Epsilon to detect a near zero floating point
  REAL(r_std),PARAMETER :: min_sechiba = 1.E-8_r_std
! The undef value used in SECHIBA
  REAL(r_std),PARAMETER :: undef_sechiba = 1.E+20_r_std
!-
! Numerical constant set to 0
  REAL(r_std),PARAMETER :: zero = 0._r_std
! Numerical constant set to 1/2
  REAL(r_std),PARAMETER :: undemi = 0.5_r_std
! Numerical constant set to 1
  REAL(r_std),PARAMETER :: un = 1._r_std
! Numerical constant set to -1
  REAL(r_std),PARAMETER :: moins_un = -1._r_std
! Numerical constant set to 2
  REAL(r_std),PARAMETER :: deux = 2._r_std
! Numerical constant set to 3
  REAL(r_std),PARAMETER :: trois = 3._r_std
! Numerical constant set to 4
  REAL(r_std),PARAMETER :: quatre = 4._r_std
! Numerical constant set to 5
  REAL(r_std),PARAMETER :: cinq = 5._r_std
! Numerical constant set to 6
  REAL(r_std),PARAMETER :: six = 6._r_std
! Numerical constant set to 8
  REAL(r_std),PARAMETER :: huit = 8._r_std
! Numerical constant set to 1000
  REAL(r_std),PARAMETER :: mille = 1000._r_std
!-
  TYPE control_type
    LOGICAL :: river_routing
    LOGICAL :: hydrol_cwrr
    LOGICAL :: ok_sechiba
    LOGICAL :: ok_co2
    LOGICAL :: ok_stomate
    LOGICAL :: ok_dgvm
    LOGICAL :: stomate_watchout
    LOGICAL :: ok_pheno
  END TYPE control_type
!--------------------
END MODULE constantes
